@@ -37,12 +37,13 @@ module Enumerize
     end
 
     def texts
-      @values.collect { |value| value.text }
+      @values.map(&:text)
     end
 
     delegate :join, to: :to_ary
 
     def ==(other)
+      return false unless other.respond_to?(:each)
       other.size == size && other.all? { |v| @values.include?(@attr.find_value(v)) }
     end
 
